Module diagnostic

Module diagnostic 

Structs

Annotation
A pointer to a subsequence in the end user’s input.
Diagnostic
A collection of information that can be rendered into a diagnostic.
DiagnosticMessage
A diagnostic message string.
DiagnosticStylesheet
DisplayDiagnostic
A type that implements std::fmt::Display for diagnostic rendering.
DisplayDiagnosticConfig
Configuration for rendering diagnostics.
DisplayDiagnostics
A type that implements std::fmt::Display for rendering a collection of diagnostics.
DummyFileResolver
A stub implementation of FileResolver intended for testing.
Input
An abstraction over a unit of user input.
LintName
A string identifier for a lint rule.
SecondaryCode
A secondary identifier for a lint diagnostic.
Span
A span represents the source of a diagnostic.
SubDiagnostic
A collection of information subservient to a diagnostic.

Enums

ConciseMessage
A representation of the kinds of messages inside a diagnostic.
DiagnosticFormat
The diagnostic output format.
DiagnosticId
Uniquely identifies the kind of a diagnostic.
DiagnosticTag
Tags that can be associated with an annotation.
HyperlinkMode
Controls whether colored diagnostic output includes hyperlinks.
Severity
SubDiagnosticSeverity
Like Severity but exclusively for sub-diagnostics.
UnifiedFile
A unified file representation for both ruff and ty.

Traits

FileResolver
A trait that facilitates the retrieval of source code from a Span.
IntoDiagnosticMessage
A trait for values that can be converted into a diagnostic message.

Functions

fmt_with_hyperlink