ConciseMessage

Enum ConciseMessage 

pub enum ConciseMessage<'a> {
    MainDiagnostic(&'a str),
    Both {
        main: &'a str,
        annotation: &'a str,
    },
    Custom(&'a str),
}
A representation of the kinds of messages inside a diagnostic.

Variants



MainDiagnostic(&'a str)

A diagnostic contains a non-empty headline message and an empty primary annotation message.



Both

A diagnostic contains a non-empty headline message and a non-empty primary annotation message.

Fields

main: &'a str
annotation: &'a str


Custom(&'a str)

A custom concise message has been provided.

Implementations

Source

impl<'a> ConciseMessage<'a>

pub fn to_str(&self) -> Cow<'a, str>