pub enum DiagnosticFormat {
Full,
Concise,
Azure,
Pylint,
Github,
}Expand description
The diagnostic output format.
Variants
Full
The default full mode will print “pretty” diagnostics.
That is, color will be used when printing to a tty.
Moreover, diagnostic messages may include additional
context and annotations on the input to help understand
the message.
Concise
Print diagnostics in a concise mode.
This will guarantee that each diagnostic is printed on a single line. Only the most important or primary aspects of the diagnostic are included. Contextual information is dropped.
This may use color when printing to a tty.
Azure
Print diagnostics in the Azure Pipelines format.
Pylint
Print diagnostics in the format emitted by Pylint.
Github
Print diagnostics in the format used by GitHub Actions workflow error annotations.