pub struct DiagnosticMessage(/* private fields */);Expand description
A diagnostic message string.
This is, for all intents and purposes, equivalent to a Box<str>.
But it does not implement std::fmt::Display. Indeed, that it its
entire reason for existence. It provides a way to pass a string
directly into diagnostic methods that accept messages without copying
that string. This works via the IntoDiagnosticMessage trait.
In most cases, callers shouldn’t need to use this. Instead, there is
a blanket trait implementation for IntoDiagnosticMessage for
anything that implements std::fmt::Display.
Implementations