DisplayDiagnosticConfig

Struct DisplayDiagnosticConfig 

pub struct DisplayDiagnosticConfig { /* private fields */ }
Configuration for rendering diagnostics.

Implementations

Source

impl DisplayDiagnosticConfig

pub fn new(program: &'static str) -> DisplayDiagnosticConfig

pub fn format(self, format: DiagnosticFormat) -> DisplayDiagnosticConfig

Whether to enable concise diagnostic output or not.

pub fn color(self, yes: bool) -> DisplayDiagnosticConfig

Whether to enable colors or not.

Configures hyperlink rendering for colored diagnostic output.

pub fn anonymized_line_numbers(self, yes: bool) -> DisplayDiagnosticConfig

Whether to anonymize line numbers in full diagnostic output.

pub fn context(self, lines: usize) -> DisplayDiagnosticConfig

Set the number of contextual lines to show around each snippet.

pub fn preview(self, yes: bool) -> DisplayDiagnosticConfig

Whether to enable preview behavior or not.

pub fn preview_enabled(&self) -> bool

pub fn prefer_rule_codes(self, yes: bool) -> DisplayDiagnosticConfig

Whether to prefer rule codes over human-readable rule names, even in preview mode.

pub fn is_prefer_rule_codes_enabled(&self) -> bool

Whether rule codes are explicitly preferred over human-readable rule names.

pub fn hide_severity(self, yes: bool) -> DisplayDiagnosticConfig

Whether to hide a diagnostic’s severity or not.

pub fn with_show_fix_status(self, yes: bool) -> DisplayDiagnosticConfig

Whether to show a fix’s availability or not.

pub fn with_fix_applicability( self, applicability: Applicability, ) -> DisplayDiagnosticConfig

Set the lowest fix applicability that should be shown.

In other words, an applicability of Safe (the default) would suppress showing fixes or fix availability for unsafe or display-only fixes.

Note that this option is currently ignored when hide_severity is false.

pub fn show_fix_status(&self) -> bool

pub fn fix_applicability(&self) -> Applicability

pub fn with_cancellation_token( self, token: Option<CancellationToken>, ) -> DisplayDiagnosticConfig