DisplayDiagnostics

Struct DisplayDiagnostics 

pub struct DisplayDiagnostics<'a> { /* private fields */ }
A type that implements std::fmt::Display for rendering a collection of diagnostics.

It is intended for collections of diagnostics that need to be serialized together, as is the case for JSON, for example.

See DisplayDiagnostic for rendering individual Diagnostics and details about the lifetime constraints.

Implementations

Source

impl<'a> DisplayDiagnostics<'a>

pub fn new( resolver: &'a dyn FileResolver, config: &'a DisplayDiagnosticConfig, diagnostics: &'a [Diagnostic], ) -> DisplayDiagnostics<'a>