pub struct Input { /* private fields */ }Expand description
An abstraction over a unit of user input.
A single unit of user input usually corresponds to a File.
This contains the actual content of that input as well as a
line index for efficiently querying its contents.