SubDiagnostic

Struct SubDiagnostic 

pub struct SubDiagnostic { /* private fields */ }
A collection of information subservient to a diagnostic.

A sub-diagnostic is always rendered after the parent diagnostic it is attached to. A parent diagnostic may have many sub-diagnostics, and it is guaranteed that they will not interleave with one another in rendering.

Currently, the order in which sub-diagnostics are rendered relative to one another (for a single parent diagnostic) is the order in which they were attached to the diagnostic.

Implementations

Source

impl SubDiagnostic

pub fn new<'a>( severity: SubDiagnosticSeverity, message: impl IntoDiagnosticMessage + 'a, ) -> SubDiagnostic

Create a new sub-diagnostic with the given severity and message.

The severity should describe the assumed level of importance to an end user.

The message is meant to be read by end users. The primary message is meant to be a single terse description (usually a short phrase) describing the group of related characteristics that the sub-diagnostic describes. Stated differently, if only one thing from a diagnostic can be shown to an end user in a particular context, it is the primary message.

Types implementing IntoDiagnosticMessage

Callers can pass anything that implements std::fmt::Display directly. If callers want or need to avoid cloning the diagnostic message, then they can also pass a DiagnosticMessage directly.

pub fn annotate(&mut self, ann: Annotation)

Add an annotation to this sub-diagnostic.

Annotations for a sub-diagnostic, like for a diagnostic, are optional. If any are added, callers should strive to make at least one of them primary. That is, it should be constructed via Annotation::primary. A diagnostic with no primary annotations is allowed, but its rendering may be sub-optimal.

Note that it is expected to be somewhat more common for sub-diagnostics to have no annotations (e.g., a simple note) than for a diagnostic to have no annotations.

pub fn annotations(&self) -> &[Annotation]

pub fn secondary_annotations(&self) -> impl Iterator<Item = &Annotation>

Returns all annotations, skipping the first primary annotation.

pub fn annotations_mut(&mut self) -> impl Iterator<Item = &mut Annotation>

Returns a mutable borrow of the annotations of this sub-diagnostic.

pub fn primary_annotation(&self) -> Option<&Annotation>

Returns a shared borrow of the “primary” annotation of this diagnostic if one exists.

When there are multiple primary annotations, then the first one that was added to this diagnostic is returned.

pub fn primary_span_ref(&self) -> Option<&Span>

Returns a reference to the primary span of this sub-diagnostic.

pub fn headline_message(&self) -> &str

Returns the headline message for this sub-diagnostic.

A sub-diagnostic always has a message, but it may be empty.

pub fn concise_message(&self) -> ConciseMessage<'_>

Introspects this sub-diagnostic and returns its message for concise formatting.

When we concisely format diagnostics, we likely want to not only include the headline message but also the message attached to the primary annotation. In particular, the primary annotation often contains essential information or context for understanding the diagnostic.

The type returned implements the std::fmt::Display trait. In most cases, just converting it to a string (or printing it) will do what you want.

pub fn severity(&self) -> SubDiagnosticSeverity