pub struct FileRevision(/* private fields */);Expand description
A number representing the revision of a file.
Two revisions that don’t compare equal signify that the file has been modified. Revisions aren’t guaranteed to be monotonically increasing or in any specific order.
Possible revisions are:
- The last modification time of the file.
- The hash of the file’s content.
- The revision as it comes from an external system, for example the LSP.
Implementations