pub enum FilePath {
System(Box<SystemPath>),
SystemVirtual(Box<SystemVirtualPath>),
Vendored(Box<VendoredPath>),
}Expand description
Path to a file.
The path abstracts that files in Ruff can come from different sources:
- a file stored on the host system.
- a virtual file stored on the host system.
- a vendored file stored in the vendored file system.
Variants
System(Box<SystemPath>)
Path to a file on the host system.
SystemVirtual(Box<SystemVirtualPath>)
Path to a virtual file on the host system.
Vendored(Box<VendoredPath>)
Path to a file vendored as part of Ruff. Stored in the vendored file system.
Implementations
Sourceimpl FilePath
impl FilePath
Sourcepub fn system(path: impl AsRef<SystemPath>) -> Self
pub fn system(path: impl AsRef<SystemPath>) -> Self
Create a new path to a file on the file system.
pub fn as_system_path(&self) -> Option<&SystemPath>
Sourcepub const fn is_system_path(&self) -> bool
pub const fn is_system_path(&self) -> bool
Returns true if the path is a file system path that points to a path on disk.
Sourcepub const fn is_system_virtual_path(&self) -> bool
pub const fn is_system_virtual_path(&self) -> bool
Returns true if the path is a file system path that is virtual i.e., it doesn’t exists on
disk.
Sourcepub const fn is_vendored_path(&self) -> bool
pub const fn is_vendored_path(&self) -> bool
Returns true if the path is a vendored path.
pub fn as_vendored_path(&self) -> Option<&VendoredPath>
Sourcepub fn to_file(&self, db: &dyn Db) -> Option<File>
pub fn to_file(&self, db: &dyn Db) -> Option<File>
Interns a virtual file system path and returns a salsa File ingredient.
Returns Some if a file for path exists and is accessible by the user. Returns None otherwise.
See system_path_to_file or vendored_path_to_file if you always have either a file
system or vendored path.
pub fn extension(&self) -> Option<&str>