pub struct DirectoryListing(/* private fields */);Expand description
A cached snapshot of the direct children in a directory.
The entries are sorted by name for efficient lookups.
Implementations
Sourceimpl DirectoryListing
impl DirectoryListing
Sourcepub fn contains_name_with_prefix(&self, prefix: &str) -> bool
pub fn contains_name_with_prefix(&self, prefix: &str) -> bool
Returns whether any entry name starts with prefix.
Sourcepub fn entry_is_file(
&self,
db: &dyn Db,
directory: &SystemPath,
name: &str,
) -> bool
pub fn entry_is_file( &self, db: &dyn Db, directory: &SystemPath, name: &str, ) -> bool
Returns whether name resolves to a file, following symbolic links.
Sourcepub fn entry_is_directory(
&self,
db: &dyn Db,
directory: &SystemPath,
name: &str,
) -> bool
pub fn entry_is_directory( &self, db: &dyn Db, directory: &SystemPath, name: &str, ) -> bool
Returns whether name resolves to a directory, following symbolic links.