pub struct DirectoryListingError { /* private fields */ }Trait Implementations
Sourceimpl Clone for DirectoryListingError
impl Clone for DirectoryListingError
Sourcefn clone(&self) -> DirectoryListingError
fn clone(&self) -> DirectoryListingError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DirectoryListingError
impl Debug for DirectoryListingError
Sourceimpl Display for DirectoryListingError
impl Display for DirectoryListingError
impl Eq for DirectoryListingError
Sourceimpl Error for DirectoryListingError
impl Error for DirectoryListingError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<Error> for DirectoryListingError
impl From<Error> for DirectoryListingError
Sourceimpl GetSize for DirectoryListingError
impl GetSize for DirectoryListingError
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER: GetSizeTracker>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)
fn get_heap_size_with_tracker<TRACKER: GetSizeTracker>( &self, tracker: TRACKER, ) -> (usize, TRACKER)
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl PartialEq for DirectoryListingError
impl PartialEq for DirectoryListingError
impl StructuralPartialEq for DirectoryListingError