pub struct FileRoot(/* private fields */);Expand description
A root path for files tracked by the database.
We currently create roots for:
- static module resolution paths
- the project root
File roots determine the durability of files and directories.
Implementations
Sourceimpl FileRoot
impl FileRoot
pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)
Sourceimpl FileRoot
impl FileRoot
pub fn new<Db_>( db: &Db_, path: Box<SystemPath>, kind_at_time_of_creation: FileRootKind, ) -> Self
pub fn builder( path: Box<SystemPath>, kind_at_time_of_creation: FileRootKind, ) -> <Self as HasBuilder>::Builder
Sourcepub fn path<'db, Db_>(
self,
db: &'db Db_,
) -> &'db <Box<SystemPath> as Deref>::Target
pub fn path<'db, Db_>( self, db: &'db Db_, ) -> &'db <Box<SystemPath> as Deref>::Target
The path of a root is guaranteed to never change.
Sourcepub fn kind_at_time_of_creation<'db, Db_>(self, db: &'db Db_) -> FileRootKind
pub fn kind_at_time_of_creation<'db, Db_>(self, db: &'db Db_) -> FileRootKind
The kind of the root at the time of its creation.
pub fn set_path<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Box<SystemPath>>
pub fn set_kind_at_time_of_creation<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = FileRootKind>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
Default debug formatting for this struct (may be useful if you define your own Debug impl)