ParsedModuleRef

Struct ParsedModuleRef 

pub struct ParsedModuleRef { /* private fields */ }
Cheap cloneable wrapper around an instance of a module AST.

Implementations

Source

impl ParsedModuleRef

pub fn module(&self) -> &ParsedModule

Returns a reference to the ParsedModule that this instance was loaded from.

pub fn get_by_index<'ast>(&'ast self, index: NodeIndex) -> AnyRootNodeRef<'ast>

Returns a reference to the AST node at the given index.

Methods from Deref<Target = Parsed<ModModule>>

pub fn syntax(&self) -> &T

Returns the syntax node represented by this parsed output.

pub fn tokens(&self) -> &Tokens

Returns all the tokens for the parsed output.

pub fn errors(&self) -> &[ParseError]

Returns a list of syntax errors found during parsing.

pub fn unsupported_syntax_errors(&self) -> &[UnsupportedSyntaxError]

Returns a list of version-related syntax errors found during parsing.

pub fn has_valid_syntax(&self) -> bool

Returns true if the parsed source code is valid i.e., it has no ParseErrors.

Note that this does not include version-related UnsupportedSyntaxErrors.

See Parsed::has_no_syntax_errors for a version that takes these into account.

pub fn has_invalid_syntax(&self) -> bool

Returns true if the parsed source code is invalid i.e., it has ParseErrors.

Note that this does not include version-related UnsupportedSyntaxErrors.

See Parsed::has_no_syntax_errors for a version that takes these into account.

pub fn has_no_syntax_errors(&self) -> bool

Returns true if the parsed source code does not contain any ParseErrors or UnsupportedSyntaxErrors.

See Parsed::has_valid_syntax for a version specific to ParseErrors.

pub fn has_syntax_errors(&self) -> bool

Returns true if the parsed source code contains any ParseErrors or UnsupportedSyntaxErrors.

See Parsed::has_invalid_syntax for a version specific to ParseErrors.

pub fn as_result(&self) -> Result<&Parsed<T>, &[ParseError]>

Returns the Parsed output as a Result, returning Ok if it has no syntax errors, or Err containing the first ParseError encountered.

Note that any unsupported_syntax_errors will not cause Err to be returned.

pub fn suite(&self) -> &ThinVec<Stmt>

Returns the module body contained in this parsed output as a Suite.