Module source

Module source 

Structs

SourceText
The source text of a file containing python code.

Enums

SourceTextError

Functions

line_index
Computes the LineIndex for file.
source_text
Reads the source text of a python text file (must be valid UTF8) or notebook.