pub fn source_text<'db>(db: &'db dyn Db, file: File) -> SourceTextExpand description
Reads the source text of a python text file (must be valid UTF8) or notebook.
pub fn source_text<'db>(db: &'db dyn Db, file: File) -> SourceTextReads the source text of a python text file (must be valid UTF8) or notebook.