pub struct PythonFile<'db>(/* private fields */);Expand description
A file paired with the Python version used to parse its contents.
This is the key for parsed::parsed_module. Including the Python version allows the same
file to be parsed for different versions within a single Salsa revision without sharing an
incompatible AST or syntax diagnostics.
Implementations
Sourceimpl PythonFile<'static>
impl PythonFile<'static>
pub fn ingredient(zalsa: &Zalsa) -> &IngredientImpl<Self>
Sourceimpl<'db> PythonFile<'db>
impl<'db> PythonFile<'db>
Sourceimpl PythonFile<'_>
impl PythonFile<'_>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
Default debug formatting for this struct (may be useful if you define your own Debug impl)