pub enum WhichError {
CannotFindBinaryPath,
CannotGetCurrentDirAndPathListEmpty,
CannotCanonicalize,
NonUtf8Path,
}Variants
CannotFindBinaryPath
An executable binary with that name was not found
CannotGetCurrentDirAndPathListEmpty
There was nowhere to search and the provided name wasn’t an absolute path
CannotCanonicalize
Failed to canonicalize the path found
NonUtf8Path
The executable exists but its path contains non UTF8 characters.