TestSystem

Struct TestSystem 

pub struct TestSystem { /* private fields */ }
System implementation intended for testing.

It uses a memory-file system by default, but can be switched to the real file system for tests verifying more advanced file system features.

Warning

Don’t use this system for production code. It’s intended for testing only.

Implementations

Source

impl TestSystem

pub fn new( inner: impl WritableSystem + RefUnwindSafe + Send + Sync + 'static, ) -> Self

pub fn set_env_var(&self, name: impl Into<String>, value: impl Into<String>)

Sets an environment variable override. This takes precedence over the inner system.

pub fn remove_env_var(&self, name: impl Into<String>)

Removes an environment variable override, making it appear as not set.

pub fn in_memory(&self) -> &InMemorySystem

Returns the InMemorySystem.

Panics

If the underlying test system isn’t the InMemorySystem.

pub fn memory_file_system(&self) -> &MemoryFileSystem

Returns the memory file system.

Panics

If the underlying test system isn’t the InMemorySystem.