pub struct VendoredFileSystem { /* private fields */ }Expand description
File system that stores all content in a static zip archive bundled as part of the Ruff binary.
“Files” in the VendoredFileSystem are read-only and immutable.
Directories are supported, but symlinks and hardlinks cannot exist.
Path separators
At time of writing (2025-07-11), this implementation always uses / as a
path separator, even in Windows environments where \ is traditionally
used as a file path separator. Namely, this is only currently used with zip
files built by crates/ty_vendored/build.rs.
Callers using this may provide paths that use a \ as a separator. It will
be transparently normalized to /.
This is particularly important because the presence of a trailing separator in a zip file is conventionally used to indicate a directory entry.
Implementations
Sourceimpl VendoredFileSystem
impl VendoredFileSystem
pub fn new_static(raw_bytes: &'static [u8]) -> Result<Self>
pub fn new(raw_bytes: Vec<u8>) -> Result<Self>
pub fn exists(&self, path: impl AsRef<VendoredPath>) -> bool
pub fn metadata(&self, path: impl AsRef<VendoredPath>) -> Result<Metadata>
pub fn is_directory(&self, path: impl AsRef<VendoredPath>) -> bool
pub fn is_file(&self, path: impl AsRef<VendoredPath>) -> bool
Sourcepub fn read_to_string(&self, path: impl AsRef<VendoredPath>) -> Result<String>
pub fn read_to_string(&self, path: impl AsRef<VendoredPath>) -> Result<String>
Read the entire contents of the zip file at path into a string
Returns an Err() if any of the following are true:
- The path does not exist in the underlying zip archive
- The path exists in the underlying zip archive, but represents a directory
- The contents of the zip file at
pathcontain invalid UTF-8
Sourcepub fn read_directory(
&self,
dir: impl AsRef<VendoredPath>,
) -> impl Iterator<Item = DirectoryEntry> + '_
pub fn read_directory( &self, dir: impl AsRef<VendoredPath>, ) -> impl Iterator<Item = DirectoryEntry> + '_
Read the direct children of the directory
identified by path.
If path is not a directory, then this will
return an empty iterator.