Structs
- Annotation
- A pointer to a subsequence in the end user’s input.
- Diagnostic
- A collection of information that can be rendered into a diagnostic.
- Diagnostic
Message - A diagnostic message string.
- Diagnostic
Stylesheet - Display
Diagnostic - A type that implements
std::fmt::Displayfor diagnostic rendering. - Display
Diagnostic Config - Configuration for rendering diagnostics.
- Display
Diagnostics - A type that implements
std::fmt::Displayfor rendering a collection of diagnostics. - Dummy
File Resolver - A stub implementation of
FileResolverintended for testing. - Input
- An abstraction over a unit of user input.
- Lint
Name - A string identifier for a lint rule.
- Secondary
Code - A secondary identifier for a lint diagnostic.
- Span
- A span represents the source of a diagnostic.
- SubDiagnostic
- A collection of information subservient to a diagnostic.
Enums
- Concise
Message - A representation of the kinds of messages inside a diagnostic.
- Diagnostic
Format - The diagnostic output format.
- Diagnostic
Id - Uniquely identifies the kind of a diagnostic.
- Diagnostic
Tag - Tags that can be associated with an annotation.
- Hyperlink
Mode - Controls whether colored diagnostic output includes hyperlinks.
- Severity
- SubDiagnostic
Severity - Like
Severitybut exclusively for sub-diagnostics. - Unified
File - A unified file representation for both ruff and ty.
Traits
- File
Resolver - A trait that facilitates the retrieval of source code from a
Span. - Into
Diagnostic Message - A trait for values that can be converted into a diagnostic message.