pub enum ConciseMessage<'a> {
MainDiagnostic(&'a str),
Both {
main: &'a str,
annotation: &'a str,
},
Custom(&'a str),
}Expand description
A representation of the kinds of messages inside a diagnostic.
Variants
MainDiagnostic(&'a str)
A diagnostic contains a non-empty headline message and an empty primary annotation message.
Both
A diagnostic contains a non-empty headline message and a non-empty primary annotation message.
Custom(&'a str)
A custom concise message has been provided.
Implementations