pub enum UnifiedFile {
Ty(File),
Ruff(SourceFile),
}Expand description
A unified file representation for both ruff and ty.
Such a representation is needed for rendering Diagnostics that can optionally contain
Annotations with Spans that need to refer to the text of a file. However, ty and ruff
use very different file types: a Copy-able salsa-interned File, and a heavier-weight
SourceFile, respectively.
This enum presents a unified interface to these two types for the sake of creating Spans and
emitting diagnostics from both ty and ruff.
Variants
Ty(File)
Ruff(SourceFile)