pub struct Span { /* private fields */ }Expand description
A span represents the source of a diagnostic.
It consists of a File and an optional range into that file. When the
range isn’t present, it semantically implies that the diagnostic refers to
the entire file. For example, when the file should be executable but isn’t.
Implementations
Sourceimpl Span
impl Span
Sourcepub fn file(&self) -> &UnifiedFile
pub fn file(&self) -> &UnifiedFile
Returns the UnifiedFile attached to this Span.
Sourcepub fn range(&self) -> Option<TextRange>
pub fn range(&self) -> Option<TextRange>
Returns the range, if available, attached to this Span.
When there is no range, it is convention to assume that this Span
refers to the corresponding File as a whole. In some cases, consumers
of this API may use the range 0..0 to represent this case.
Sourcepub fn with_range(self, range: TextRange) -> Span
pub fn with_range(self, range: TextRange) -> Span
Returns a new Span with the given range attached to it.
Sourcepub fn with_optional_range(self, range: Option<TextRange>) -> Span
pub fn with_optional_range(self, range: Option<TextRange>) -> Span
Returns a new Span with the given optional range attached to it.
Sourcepub fn expect_ty_file(&self) -> File
pub fn expect_ty_file(&self) -> File
Returns the File attached to this Span.
Panics if the file is a UnifiedFile::Ruff instead of a UnifiedFile::Ty.
Sourcepub fn as_ruff_file(&self) -> Option<&SourceFile>
pub fn as_ruff_file(&self) -> Option<&SourceFile>
Returns the SourceFile attached to this Span.