pub struct File(/* private fields */);Expand description
A file-system path that’s either stored on the host system’s file system or in the vendored file system.
Ordering
Ordering is based on the file’s salsa-assigned id and not on its values. The id may change between runs.
Implementations
Sourceimpl File
impl File
pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)
Sourceimpl File
impl File
pub fn new<Db_>(db: &Db_, path: FilePath) -> Self
pub fn builder(path: FilePath) -> <Self as HasBuilder>::Builder
Sourcepub fn permissions<'db, Db_>(self, db: &'db Db_) -> Option<u32>
pub fn permissions<'db, Db_>(self, db: &'db Db_) -> Option<u32>
The unix permissions of the file. Only supported on unix systems. Always None on Windows
or when the file has been deleted.
Sourcepub fn revision<'db, Db_>(self, db: &'db Db_) -> FileRevision
pub fn revision<'db, Db_>(self, db: &'db Db_) -> FileRevision
The path revision. A file or directory has changed if the revisions don’t compare equal.
Sourcepub fn status<'db, Db_>(self, db: &'db Db_) -> FileStatus
pub fn status<'db, Db_>(self, db: &'db Db_) -> FileStatus
The status of the file.
Salsa doesn’t support deleting inputs. The only way to signal dependent queries that
the file has been deleted is to change the status to Deleted.
Sourcepub fn source_text_override<'db, Db_>(
self,
db: &'db Db_,
) -> &'db Option<SourceText>
pub fn source_text_override<'db, Db_>( self, db: &'db Db_, ) -> &'db Option<SourceText>
Overrides the result of source_text.
This is useful when running queries after modifying a file’s content but before the content is written to disk. For example, to verify that the applied fixes didn’t introduce any new errors.
The override gets automatically removed the next time the file changes.
pub fn set_path<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = FilePath> + use<'db, Db_>
pub fn set_permissions<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Option<u32>> + use<'db, Db_>
pub fn set_revision<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = FileRevision> + use<'db, Db_>
pub fn set_status<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = FileStatus> + use<'db, Db_>
pub fn set_source_text_override<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Option<SourceText>> + use<'db, Db_>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
Default debug formatting for this struct (may be useful if you define your own Debug impl)
Sourceimpl File
impl File
Sourcepub fn read_to_string(&self, db: &dyn Db) -> Result<String>
pub fn read_to_string(&self, db: &dyn Db) -> Result<String>
Reads the content of the file into a String.
Reading the same file multiple times isn’t guaranteed to return the same content. It’s possible that the file has been modified in between the reads.
Sourcepub fn read_to_notebook(&self, db: &dyn Db) -> Result<Notebook, NotebookError>
pub fn read_to_notebook(&self, db: &dyn Db) -> Result<Notebook, NotebookError>
Reads the content of the file into a Notebook.
Reading the same file multiple times isn’t guaranteed to return the same content. It’s possible that the file has been modified in between the reads.
Sourcepub fn sync_path(db: &mut dyn Db, path: &SystemPath)
pub fn sync_path(db: &mut dyn Db, path: &SystemPath)
Refreshes the file metadata by querying the file system if needed.
Directory listings are invalidated if the path’s file status changed, its prior status is
unknown, or if path is itself a directory.
Sourcepub fn sync_path_only(db: &mut dyn Db, path: &SystemPath)
pub fn sync_path_only(db: &mut dyn Db, path: &SystemPath)
Refreshes only the file metadata by querying the file system if needed.
This specifically does not invalidate any directory listings.
Sourcepub fn sync_virtual_path(db: &mut dyn Db, path: &SystemVirtualPath)
pub fn sync_virtual_path(db: &mut dyn Db, path: &SystemVirtualPath)
Increments the revision for the virtual file at path.
Sourcepub fn sync(self, db: &mut dyn Db)
pub fn sync(self, db: &mut dyn Db)
Syncs the File’s state with the state of the file on the system.
Sourcepub fn is_stub(self, db: &dyn Db) -> bool
pub fn is_stub(self, db: &dyn Db) -> bool
Returns true if the file should be analyzed as a type stub.
Sourcepub fn is_package_stub(self, db: &dyn Db) -> bool
pub fn is_package_stub(self, db: &dyn Db) -> bool
Returns true if the file is an __init__.pyi
Sourcepub fn is_package(self, db: &dyn Db) -> bool
pub fn is_package(self, db: &dyn Db) -> bool
Returns true if the file is an __init__.pyi
pub fn source_type(self, db: &dyn Db) -> PySourceType