pub struct ParsedModule { /* private fields */ }Expand description
A wrapper around a parsed module.
This type manages instances of the module AST. A particular instance of the AST
is represented with the ParsedModuleRef type.
Implementations
Sourceimpl ParsedModule
impl ParsedModule
pub fn new( file: File, python_version: PythonVersion, parsed: Parsed<ModModule>, ) -> Self
Sourcepub fn load(&self, db: &dyn Db) -> ParsedModuleRef
pub fn load(&self, db: &dyn Db) -> ParsedModuleRef
Loads a reference to the parsed module.
Note that holding on to the reference will prevent garbage collection of the AST. This method will reparse the module if it has been collected.
Sourcepub fn clear(&self)
pub fn clear(&self)
Clear the parsed module, dropping the AST once all references to it are dropped.
Sourcepub fn python_version(&self) -> PythonVersion
pub fn python_version(&self) -> PythonVersion
Returns the Python version used to parse this module.