pub struct TestSystem { /* private fields */ }Expand description
System implementation intended for testing.
It uses a memory-file system by default, but can be switched to the real file system for tests verifying more advanced file system features.
Warning
Don’t use this system for production code. It’s intended for testing only.
Implementations
Sourceimpl TestSystem
impl TestSystem
pub fn new( inner: impl WritableSystem + RefUnwindSafe + Send + Sync + 'static, ) -> Self
Sourcepub fn set_env_var(&self, name: impl Into<String>, value: impl Into<String>)
pub fn set_env_var(&self, name: impl Into<String>, value: impl Into<String>)
Sets an environment variable override. This takes precedence over the inner system.
Sourcepub fn remove_env_var(&self, name: impl Into<String>)
pub fn remove_env_var(&self, name: impl Into<String>)
Removes an environment variable override, making it appear as not set.
Sourcepub fn in_memory(&self) -> &InMemorySystem
pub fn in_memory(&self) -> &InMemorySystem
Sourcepub fn memory_file_system(&self) -> &MemoryFileSystem
pub fn memory_file_system(&self) -> &MemoryFileSystem